SystemOrganization addCategory: #BattleShipTest!

TestCase subclass: #BattleShipTestCase
	instanceVariableNames: 'factory player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BattleShipTest'!

!BattleShipTestCase methodsFor: 'tests' stamp: 'YuLin 5/3/2013 15:27'!
setUp
	factory := ShipFactory new.
	player := Player new gridHeight: 10 gridWidth: 10 name: 'Oscar' factory: factory.
	player addShip: 'Minesweeper' at: 5@2 rotated: false.
	player addShip: 'Minesweeper' at: 8@2 rotated: false.
	player addShip: 'Destroyer' at: 8@10 rotated: true.
	player addShip: 'Battleship' at: 2@1 rotated: false.
	! !

!BattleShipTestCase methodsFor: 'tests' stamp: 'YuLin 5/3/2013 13:11'!
test1
	player peekGridToGui: player! !

!BattleShipTestCase methodsFor: 'tests' stamp: 'YuLin 5/3/2013 14:17'!
test2
	player hit: 1@1.
	player peekGridToGui: nil.
	player hit: 4@3.
	player peekGridToGui: nil.
	player hit: 10@8.
	player peekGridToGui: nil.
	player hit: 5@3.
	player peekGridToGui: nil.
	player hit: 5@3.
	player peekGridToGui: nil.
	player hit: 5@2.
	player peekGridToGui: nil.
	player hit: 5@2.
	player peekGridToGui: nil.
	player hit: 6@10.
	player peekGridToGui: nil.
	player hit: 8@3.
	player peekGridToGui: nil.! !

!BattleShipTestCase methodsFor: 'tests' stamp: 'YuLin 5/3/2013 15:27'!
testGrid
	|grid ship1 ship2|
	grid := Grid new height: 10 width: 10.
	ship1 := Ship named: 'Destroyer' withLayout: 'rr'.
	ship2 := Ship named: 'Battleship' withLayout: 'rrr'.
	ship2 rotate ! !

TestCase subclass: #HitResultTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BattleShipTest'!

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 17:39'!
testConstruction
	| result |
	result := HitResult new.
	
	self assert: result isHit = false.
	self assert: result isSunk = false.
	self assert: result isSurrender = false.
	self assert: result asString = 'MISS'! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 17:48'!
testHit
	| result |
	result := HitResult new.
	result hit.
	self assert: result isHit = true.
	self assert: result isSunk = false.
	self assert: result isSurrender = false.
	self assert: result asString = 'HIT'.! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 18:03'!
testHitandSink
	| result |
	
	result := HitResult new.
	result hit.
	result sunk: (ShipFactory new buildShip: 'Minesweeper').
	
	self assert: result isHit = true.
	self assert: result isSunk = true.
	self assert: result isSurrender = false.
	self assert: result asString = ('SUNK ','Minesweeper').! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 18:04'!
testHitandSinkandSurrender
	| result |
	
	result := HitResult new.
	result hit.
	result sunk: (ShipFactory new buildShip: 'Minesweeper').
	result surrender.
	
	self assert: result isHit = true.
	self assert: result isSunk = true.
	self assert: result isSurrender = true.
	self assert: result asString = ('SURRENDER').! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 18:04'!
testSink
	
	| result |
	result := HitResult new.
	result sunk: (ShipFactory new buildShip: 'Minesweeper').
	self assert: result isHit = false.
	self assert: result isSunk = true.
	self assert: result isSurrender = false.
	self assert: result asString = ('SUNK', ' Minesweeper').! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 18:04'!
testSinkAndSurrender
	| result |
	
	result := HitResult new.
	result hit.
	result sunk: (ShipFactory new buildShip: 'Minesweeper').
	result surrender.
	
	self assert: result isHit = true.
	self assert: result isSunk = true.
	self assert: result isSurrender = true.
	self assert: result asString = ('SURRENDER').! !

!HitResultTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 18:01'!
testSurrender
	| result |
	
	result := HitResult new.
	result surrender.
	
	self assert: result isHit = false.
	self assert: result isSunk = false.
	self assert: result isSurrender = true.
	self assert: result asString = ('SURRENDER').! !

TestCase subclass: #LayoutTest
	instanceVariableNames: 'layoutPattern1 layoutPattern2 basePattern basePatternRotated baseLayout doubleLayout complexLayout'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BattleShipTest'!

!LayoutTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 16:42'!
assertRotateLayout: aLayout withPattern: aPattern andInverted: anInvertedPattern
	aLayout rotate.
	self assert: aLayout  layout = anInvertedPattern  .

	aLayout rotate.
	self assert: aLayout  layout = aPattern  .! !

!LayoutTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 16:12'!
setUp
	"D->L
	L->U
	R->D
	U->R"

	basePattern := 'rldu'.
	basePatternRotated := 'dulr'.
	layoutPattern1 := basePattern, basePattern .
	layoutPattern2 := basePattern, '|extra1|extra2'.
	
	baseLayout := Layout withLayout: basePattern.
	self assert: baseLayout layout = basePattern.
	
	doubleLayout := Layout withLayout: layoutPattern1.
	self assert: doubleLayout layout = layoutPattern1.
	
	complexLayout := Layout withLayout: layoutPattern2 .
	self assert: complexLayout layout = basePattern.! !

!LayoutTest methodsFor: 'as yet unclassified' stamp: 'MihaiCodoban 5/4/2013 16:44'!
testRotate
	self assertRotateLayout: baseLayout withPattern: basePattern andInverted: basePatternRotated .
	self assertRotateLayout: doubleLayout  withPattern: basePattern, basePattern  andInverted:  basePatternRotated, basePatternRotated.
	self assertRotateLayout: complexLayout withPattern: basePattern andInverted: basePatternRotated .! !
